Tutorial
========


This tutorial is organized as a series of examples that highlight 
gensim's various features.  It is assumed that the reader is familiar with
Vector Space Modeling and the Python language and has read the :doc:`intro`.
